package Moose::Meta::Attribute::Custom::Trait::KiokuDB::Lazy;
BEGIN {
  $Moose::Meta::Attribute::Custom::Trait::KiokuDB::Lazy::AUTHORITY = 'cpan:NUFFIN';
}
{
  $Moose::Meta::Attribute::Custom::Trait::KiokuDB::Lazy::VERSION = '0.55';
}

use KiokuDB::Meta::Attribute::Lazy;

__PACKAGE__

__END__

=pod

=head1 NAME

Moose::Meta::Attribute::Custom::Trait::KiokuDB::Lazy

=head1 VERSION

version 0.55

=head1 AUTHOR

Yuval Kogman <nothingmuch@woobling.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2013 by Yuval Kogman, Infinity Interactive.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
